import React, { useEffect, useState } from 'react'
import { Link, useLocation, useParams } from 'react-router-dom'
import axios from 'axios'
import { API_BASE_URL, SITE_TITLE } from '../config'
import NicoViewer from '../components/NicoViewer'

type Post = { id:         number
              url:        string
              title:      string
              thumbnail:  string
              tags:       { name: string }[] }

const PostDetailPage = () => {
  const { id } = useParams ()
  const [post, setPost] = useState<Post | null> (null)

  const location = useLocation ()

  useEffect (() => {
    if (!(id))
      return
    void (axios.get (`/api/posts/${ id }`)
          .then (res => setPost (res.data))
          .catch (err => console.error ('うんち!', err)))
  }, [id])

  if (!(post))
    return <div>Loading...</div>

  document.title = `${ post.url } | ${ SITE_TITLE }`

  const url = new URL (post.url)

  return (
      <div className="p-4">
        {url.hostname.split ('.').slice (-2).join ('.') === 'nicovideo.jp' ? (
            <NicoViewer id={url.pathname.match (/(?<=\/watch\/)[a-zA-Z0-9]+?(?=\/|$)/)[0]}
                        width="640"
                        height="360" />
            ) : (
            <img src={post.thumbnail} alt={post.url} className="mb-4 w-full" />
            )}
      </div>
      )
}

export default PostDetailPage
